@@ -9,7 +9,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 sub dl_load_flags { 0x01 };
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 @EXPORT = qw();
 @EXPORT_OK = qw();
 %EXPORT_TAGS = ();
@@ -62,7 +62,7 @@ sub gl_paint_state
 sub gl_select
 {
 	my $ctx = shift-> {__gl_context};
-	Prima::OpenGL::context_make_current($ctx) if $ctx;
+	return $ctx ? Prima::OpenGL::context_make_current($ctx) : 0;
 }
 
 sub gl_unselect
